Module: Google::Apis::MerchantapiLfpV1beta
- Defined in:
- lib/google/apis/merchantapi_lfp_v1beta.rb,
lib/google/apis/merchantapi_lfp_v1beta/classes.rb,
lib/google/apis/merchantapi_lfp_v1beta/service.rb,
lib/google/apis/merchantapi_lfp_v1beta/gem_version.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb
Overview
Merchant API
Programmatically manage your Merchant Center Accounts.
Defined Under Namespace
Classes: CountrySettings, Empty, InventoryStats, LfpInventory, LfpMerchantState, LfpSale, LfpStore, LfpStoreState, ListLfpStoresResponse, MerchantService, Price, ProductChange, ProductStatusChangeMessage
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-merchantapi_lfp_v1beta gem
"0.12.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260527"- VERSION =
Version of the Merchant API this client connects to. This is NOT the gem version.
'LfpV1beta'- AUTH_CONTENT =
Manage your product listings and accounts for Google Shopping
'https://www.googleapis.com/auth/content'