Class: Google::Apis::MerchantapiLfpV1beta::CountrySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_lfp_v1beta/classes.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb

Overview

Country-specific settings for the merchant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CountrySettings

Returns a new instance of CountrySettings.



68
69
70
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 68

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#free_local_listings_enabledBoolean Also known as: free_local_listings_enabled?

True if this merchant has enabled free local listings in MC. Corresponds to the JSON property freeLocalListingsEnabled

Returns:

  • (Boolean)


32
33
34
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 32

def free_local_listings_enabled
  @free_local_listings_enabled
end

#instock_serving_verification_stateString

Output only. The verification state of this merchant's instock serving feature. Corresponds to the JSON property instockServingVerificationState

Returns:

  • (String)


38
39
40
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 38

def instock_serving_verification_state
  @instock_serving_verification_state
end

#inventory_verification_stateString

Output only. The verification state of this merchant's inventory check. Corresponds to the JSON property inventoryVerificationState

Returns:

  • (String)


43
44
45
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 43

def inventory_verification_state
  @inventory_verification_state
end

#local_inventory_ads_enabledBoolean Also known as: local_inventory_ads_enabled?

True if this merchant has enabled local inventory ads in MC. Corresponds to the JSON property localInventoryAdsEnabled

Returns:

  • (Boolean)


48
49
50
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 48

def local_inventory_ads_enabled
  @local_inventory_ads_enabled
end

#pickup_serving_verification_stateString

Output only. The verification state of this merchant's pickup serving feature. Corresponds to the JSON property pickupServingVerificationState

Returns:

  • (String)


54
55
56
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 54

def pickup_serving_verification_state
  @pickup_serving_verification_state
end

#product_page_typeString

Output only. The product page type selected by this merchant. Corresponds to the JSON property productPageType

Returns:

  • (String)


59
60
61
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 59

def product_page_type
  @product_page_type
end

#region_codeString

Required. The CLDR territory code for the country for which these settings are defined. Corresponds to the JSON property regionCode

Returns:

  • (String)


66
67
68
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 66

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73
74
75
76
77
78
79
80
81
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 73

def update!(**args)
  @free_local_listings_enabled = args[:free_local_listings_enabled] if args.key?(:free_local_listings_enabled)
  @instock_serving_verification_state = args[:instock_serving_verification_state] if args.key?(:instock_serving_verification_state)
  @inventory_verification_state = args[:inventory_verification_state] if args.key?(:inventory_verification_state)
  @local_inventory_ads_enabled = args[:local_inventory_ads_enabled] if args.key?(:local_inventory_ads_enabled)
  @pickup_serving_verification_state = args[:pickup_serving_verification_state] if args.key?(:pickup_serving_verification_state)
  @product_page_type = args[:product_page_type] if args.key?(:product_page_type)
  @region_code = args[:region_code] if args.key?(:region_code)
end