Class: Google::Apis::MerchantapiLfpV1beta::InventoryStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_lfp_v1beta/classes.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb

Overview

The inventory statistics for a merchant.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventoryStats

Returns a new instance of InventoryStats.



128
129
130
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#submitted_entriesFixnum

Number of entries (understanding entry as a pair of product and store) that were built based on provided inventories/sales and submitted to Google. Corresponds to the JSON property submittedEntries

Returns:

  • (Fixnum)


108
109
110
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 108

def 
  @submitted_entries
end

#submitted_in_stock_entriesFixnum

Number of submitted in stock entries. Corresponds to the JSON property submittedInStockEntries

Returns:

  • (Fixnum)


113
114
115
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 113

def 
  @submitted_in_stock_entries
end

#submitted_productsFixnum

Number of products from provided inventories/sales that were created from matches to existing online products provided by the merchant or to the Google catalog. Corresponds to the JSON property submittedProducts

Returns:

  • (Fixnum)


120
121
122
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 120

def 
  @submitted_products
end

#unsubmitted_entriesFixnum

Number of entries that were built based on provided inventories/sales and couldn't be submitted to Google due to errors like missing product. Corresponds to the JSON property unsubmittedEntries

Returns:

  • (Fixnum)


126
127
128
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 126

def unsubmitted_entries
  @unsubmitted_entries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



133
134
135
136
137
138
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 133

def update!(**args)
  @submitted_entries = args[:submitted_entries] if args.key?(:submitted_entries)
  @submitted_in_stock_entries = args[:submitted_in_stock_entries] if args.key?(:submitted_in_stock_entries)
  @submitted_products = args[:submitted_products] if args.key?(:submitted_products)
  @unsubmitted_entries = args[:unsubmitted_entries] if args.key?(:unsubmitted_entries)
end