Class: Google::Apis::MerchantapiLfpV1beta::LfpStore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/merchantapi_lfp_v1beta/classes.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb

Overview

A store for the merchant. This will be used to match to a store under the Google Business Profile of the target merchant. If a matching store can't be found, the inventories or sales submitted with the store code will not be used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfpStore

Returns a new instance of LfpStore.



475
476
477
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcid_categoryArray<String>

Optional. Google My Business category id. Corresponds to the JSON property gcidCategory

Returns:

  • (Array<String>)


406
407
408
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 406

def gcid_category
  @gcid_category
end

#matching_stateString

Optional. Output only. The state of matching to a Google Business Profile. See matchingStateHint for further details if no match is found. Corresponds to the JSON property matchingState

Returns:

  • (String)


412
413
414
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 412

def matching_state
  @matching_state
end

#matching_state_hintString

Optional. Output only. The hint of why the matching has failed. This is only set when matchingState=STORE_MATCHING_STATE_FAILED. Possible values are: - " linked-store-not-found": There aren't any Google Business Profile stores available for matching. - "store-match-not-found": The provided LfpStore couldn't be matched to any of the connected Google Business Profile stores. Merchant Center account is connected correctly and stores are available on Google Business Profile, but the LfpStore location address does not match with Google Business Profile stores' addresses. Update the LfpStore address or Google Business Profile store address to match correctly. - "store-match- unverified": The provided LfpStore couldn't be matched to any of the connected Google Business Profile stores, as the matched Google Business Profile store is unverified. Go through the Google Business Profile verification process to match correctly. Corresponds to the JSON property matchingStateHint

Returns:

  • (String)


429
430
431
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 429

def matching_state_hint
  @matching_state_hint
end

#nameString

Output only. Identifier. The name of the LfpStore resource. Format: accounts/account/lfpStores/target_merchant~store_code` Corresponds to the JSON propertyname`

Returns:

  • (String)


435
436
437
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 435

def name
  @name
end

#phone_numberString

Optional. The store phone number in E.164 format. Example: +15556767888 Corresponds to the JSON property phoneNumber

Returns:

  • (String)


441
442
443
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 441

def phone_number
  @phone_number
end

#place_idString

Optional. The Google Place Id of the store location. Corresponds to the JSON property placeId

Returns:

  • (String)


447
448
449
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 447

def place_id
  @place_id
end

#store_addressString

Required. The street address of the store. Example: 1600 Amphitheatre Pkwy, Mountain View, CA 94043, USA. Corresponds to the JSON property storeAddress

Returns:

  • (String)


453
454
455
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 453

def store_address
  @store_address
end

#store_codeString

Required. Immutable. A store identifier that is unique for the target merchant. Corresponds to the JSON property storeCode

Returns:

  • (String)


458
459
460
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 458

def store_code
  @store_code
end

#store_nameString

Optional. The merchant or store name. Corresponds to the JSON property storeName

Returns:

  • (String)


463
464
465
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 463

def store_name
  @store_name
end

#target_accountFixnum

Required. The Merchant Center id of the merchant to submit the store for. Corresponds to the JSON property targetAccount

Returns:

  • (Fixnum)


468
469
470
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 468

def 
  @target_account
end

#website_uriString

Optional. The website URL for the store or merchant. Corresponds to the JSON property websiteUri

Returns:

  • (String)


473
474
475
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 473

def website_uri
  @website_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 480

def update!(**args)
  @gcid_category = args[:gcid_category] if args.key?(:gcid_category)
  @matching_state = args[:matching_state] if args.key?(:matching_state)
  @matching_state_hint = args[:matching_state_hint] if args.key?(:matching_state_hint)
  @name = args[:name] if args.key?(:name)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @place_id = args[:place_id] if args.key?(:place_id)
  @store_address = args[:store_address] if args.key?(:store_address)
  @store_code = args[:store_code] if args.key?(:store_code)
  @store_name = args[:store_name] if args.key?(:store_name)
  @target_account = args[:target_account] if args.key?(:target_account)
  @website_uri = args[:website_uri] if args.key?(:website_uri)
end