Class: Google::Apis::MerchantapiLfpV1beta::LfpStoreState
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiLfpV1beta::LfpStoreState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_lfp_v1beta/classes.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb
Overview
The state of a specific merchant's store.
Instance Attribute Summary collapse
-
#matching_state ⇒ String
Output only.
-
#matching_state_hint ⇒ String
The hint of why the matching has failed (only set if matching_state is FAILED).
-
#store_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfpStoreState
constructor
A new instance of LfpStoreState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfpStoreState
Returns a new instance of LfpStoreState.
514 515 516 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#matching_state ⇒ String
Output only. The store matching state.
Corresponds to the JSON property matchingState
502 503 504 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 502 def matching_state @matching_state end |
#matching_state_hint ⇒ String
The hint of why the matching has failed (only set if matching_state is FAILED).
Corresponds to the JSON property matchingStateHint
507 508 509 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 507 def matching_state_hint @matching_state_hint end |
#store_code ⇒ String
Required. Immutable. The identifier of this store.
Corresponds to the JSON property storeCode
512 513 514 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 512 def store_code @store_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
519 520 521 522 523 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 519 def update!(**args) @matching_state = args[:matching_state] if args.key?(:matching_state) @matching_state_hint = args[:matching_state_hint] if args.key?(:matching_state_hint) @store_code = args[:store_code] if args.key?(:store_code) end |