Class: Google::Apis::MerchantapiLfpV1beta::LfpInventory
- Inherits:
-
Object
- Object
- Google::Apis::MerchantapiLfpV1beta::LfpInventory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/merchantapi_lfp_v1beta/classes.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb,
lib/google/apis/merchantapi_lfp_v1beta/representations.rb
Overview
Local Inventory for the merchant.
Instance Attribute Summary collapse
-
#availability ⇒ String
Required.
-
#collection_time ⇒ String
Optional.
-
#content_language ⇒ String
Required.
-
#feed_label ⇒ String
Optional.
-
#gtin ⇒ String
Optional.
-
#name ⇒ String
Output only.
-
#offer_id ⇒ String
Required.
-
#pickup_method ⇒ String
Optional.
-
#pickup_sla ⇒ String
Optional.
-
#price ⇒ Google::Apis::MerchantapiLfpV1beta::Price
The price represented as a number and currency.
-
#quantity ⇒ Fixnum
Optional.
-
#region_code ⇒ String
Required.
-
#store_code ⇒ String
Required.
-
#target_account ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfpInventory
constructor
A new instance of LfpInventory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfpInventory
Returns a new instance of LfpInventory.
233 234 235 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability ⇒ String
Required. Availability of the product at this store. For accepted attribute
values, see the local product inventory data specification
Corresponds to the JSON property availability
150 151 152 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 150 def availability @availability end |
#collection_time ⇒ String
Optional. The time when the inventory is collected. If not set, it will be set
to the time when the inventory is submitted.
Corresponds to the JSON property collectionTime
156 157 158 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 156 def collection_time @collection_time end |
#content_language ⇒ String
Required. The two-letter ISO 639-1 language code for the item.
Corresponds to the JSON property contentLanguage
161 162 163 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 161 def content_language @content_language end |
#feed_label ⇒ String
Optional. The feed label for the product. If this is not set, it will
default to regionCode.
Corresponds to the JSON property feedLabel
168 169 170 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 168 def feed_label @feed_label end |
#gtin ⇒ String
Optional. The Global Trade Item Number of the product.
Corresponds to the JSON property gtin
173 174 175 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 173 def gtin @gtin end |
#name ⇒ String
Output only. Identifier. The name for the LfpInventory resource. Format:
accounts/account/lfpInventories/target_merchant~store_code~offer`
Corresponds to the JSON propertyname`
179 180 181 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 179 def name @name end |
#offer_id ⇒ String
Required. Immutable. A unique identifier for the product. If both inventories
and sales are submitted for a merchant, this id should match for the same
product. Note: if the merchant sells the same product new and used, they
should have different IDs.
Corresponds to the JSON property offerId
187 188 189 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 187 def offer_id @offer_id end |
#pickup_method ⇒ String
Optional. Supported pickup method for this offer. Unless the value is "not
supported", this field must be submitted together with pickupSla. For
accepted attribute values, see the local product inventory data specification.
Corresponds to the JSON property pickupMethod
195 196 197 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 195 def pickup_method @pickup_method end |
#pickup_sla ⇒ String
Optional. Expected date that an order will be ready for pickup relative to the
order date. Must be submitted together with pickupMethod. For accepted
attribute values, see the local product inventory data specification.
Corresponds to the JSON property pickupSla
203 204 205 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 203 def pickup_sla @pickup_sla end |
#price ⇒ Google::Apis::MerchantapiLfpV1beta::Price
The price represented as a number and currency.
Corresponds to the JSON property price
208 209 210 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 208 def price @price end |
#quantity ⇒ Fixnum
Optional. Quantity of the product available at this store. Must be greater
than or equal to zero.
Corresponds to the JSON property quantity
214 215 216 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 214 def quantity @quantity end |
#region_code ⇒ String
Required. The CLDR territory code for the country where the product is sold.
Corresponds to the JSON property regionCode
220 221 222 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 220 def region_code @region_code end |
#store_code ⇒ String
Required. The identifier of the merchant's store. Either the store code
inserted through InsertLfpStore or the store code in the Business Profile.
Corresponds to the JSON property storeCode
226 227 228 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 226 def store_code @store_code end |
#target_account ⇒ Fixnum
Required. The Merchant Center ID of the merchant to submit the inventory for.
Corresponds to the JSON property targetAccount
231 232 233 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 231 def target_account @target_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/google/apis/merchantapi_lfp_v1beta/classes.rb', line 238 def update!(**args) @availability = args[:availability] if args.key?(:availability) @collection_time = args[:collection_time] if args.key?(:collection_time) @content_language = args[:content_language] if args.key?(:content_language) @feed_label = args[:feed_label] if args.key?(:feed_label) @gtin = args[:gtin] if args.key?(:gtin) @name = args[:name] if args.key?(:name) @offer_id = args[:offer_id] if args.key?(:offer_id) @pickup_method = args[:pickup_method] if args.key?(:pickup_method) @pickup_sla = args[:pickup_sla] if args.key?(:pickup_sla) @price = args[:price] if args.key?(:price) @quantity = args[:quantity] if args.key?(:quantity) @region_code = args[:region_code] if args.key?(:region_code) @store_code = args[:store_code] if args.key?(:store_code) @target_account = args[:target_account] if args.key?(:target_account) end |